from gptshell.GPTshell import GPTshell
import argparse
import subprocess
import platform

def main():
  parser = argparse.ArgumentParser(description="Convert text to command and vice versa.")
  parser.add_argument("-ttc", "--text_to_command", help="Execute a shell command by providing its description.", nargs=argparse.REMAINDER)
  parser.add_argument("-ctt", "--command_to_text", help="Get the description of a shell command.", nargs=argparse.REMAINDER)
  args = parser.parse_args()
  LLMCommands = GPTshell()
  if args.text_to_command:
    output = LLMCommands.text_to_command(args.text_to_command)
    print(f"\033[1;32;40m{output}\033[0m Do you want to run this command? (y/n)", end='')
    if input().lower() == 'y':
      if platform.system() == 'Windows':
        result = subprocess.run(["powershell", "-Command", output], capture_output=True, text=True)
        print(result.stdout)
      elif platform.system() == 'Linux':
        result = subprocess.run(output, shell=True, capture_output=True, text=True)
        print(result.stdout)
  if args.command_to_text:
    output = LLMCommands.command_to_text(args.command_to_text)
    print(f"\033[1;34;40m{output}\033[0m")

  if not any(vars(args).values()):
    parser.print_help()


from langchain import OpenAI, LLMChain, PromptTemplate
import platform

class GPTshell:
  def __init__(self):
    self.system = platform.system()
  def text_to_command(self, prompt: str, num_outputs: int = 1):
    template_text_to_command = PromptTemplate(input_variables=["num_outputs","human_input"], template="""Convert the input to {num_outputs}"""+ self.system + """possible  command: {human_input}""")
    llm = LLMChain(llm=OpenAI(temperature=0), prompt=template_text_to_command, verbose=False)
    return llm.predict(human_input=prompt, num_outputs=num_outputs).strip()
  
  def command_to_text(self, prompt: str):
    template_command_to_text = PromptTemplate(input_variables=["human_input"], template="""Describe the """ + self.system + """ command in English Language: {human_input}""")
    llm = LLMChain(llm=OpenAI(temperature=0), prompt=template_command_to_text, verbose=False)
    return llm.predict(human_input=prompt).strip()


from setuptools import setup, find_packages

setup(
    name='gptshell',
    version='1.0.8',
    scripts=['gptshell/GPTshell.py'],
    author='minhalvp (Minhal Valiya Peedikakkal)',
    description='A simple command line interface which converts a description of a command into the command itself and vice versa.',
    install_requires=['langchain'],
    entry_points={"console_scripts": ["gsh = gptshell.gptsh:main"]},
    packages=find_packages(),
    keywords=['python','langchain','gpt','openai','cli'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)